@@ -4,7 +4,7 @@
 #ifndef __TOKENIZER_H
 #define __TOKENIZER_H
 
-#include <inttypes.h>
+#include <stdint.h>
 
 #ifdef __cplusplus
 extern "C" {
